@@ -17,8 +17,17 @@ AUDIO_TYPES = {
         'audio/x-wave',
         'audio/wave',
         'audio/wav'
+    ],
+    '.weba': [
+        'audio/webm'
+    ],
+    '.webm': [
+        'audio/webm'
     ]
 }
+FIX_FORMATS = {
+    'weba': 'webm'
+}
 
 for k, v in AUDIO_TYPES.items():
     for f in v:
